<?php
/**
 * This file is part of the official Amazon Checkout extension for Magento 1.x
 *
 * (c) 2020 creativestyle GmbH. All Rights reserved
 *
 * Distribution of the derivatives reusing, transforming or being built upon
 * this software, is not allowed without explicit written permission granted
 * by creativestyle GmbH
 *
 * @category   Creativestyle
 * @package    Creativestyle_AmazonCheckout
 * @copyright  2020 creativestyle GmbH
 * @author     Marek Stefan <ticket@creativestyle.de>
 */

class Creativestyle_AmazonCheckout_Block_Checkout extends Creativestyle_AmazonCheckout_Block_Template
{
    /**
     * Payment method title to display on the frontend
     *
     * @var string|null
     */
    protected $_paymentMethodTitle = null;

    /**
     * @inheritDoc
     */
    public function isActive()
    {
        return parent::isActive() && $this->_getConfig()->isPayActive();
    }

    /**
     * Get HTML output for specified address
     *
     * @param Mage_Sales_Model_Quote_Address $address
     * @return string
     * @api
     */
    public function renderAddress($address)
    {
        return $address->format('html');
    }

    /**
     * @return Mage_Sales_Model_Quote_Address
     * @api
     */
    public function getShippingAddress()
    {
        return $this->_getQuote()->getShippingAddress();
    }

    /**
     * @return Mage_Sales_Model_Quote_Address
     * @api
     */
    public function getBillingAddress()
    {
        return $this->_getQuote()->getBillingAddress();
    }

    /**
     * @return string|null
     * @api
     */
    public function getPaymentMethodTitle()
    {
        return $this->_paymentMethodTitle;
    }

    /**
     * @param string $paymentMethodTitle
     * @return $this
     * @api
     */
    public function setPaymentMethodTitle($paymentMethodTitle)
    {
        $this->_paymentMethodTitle = $paymentMethodTitle;
        return $this;
    }
}
