<?php
/**
 * This file is part of the official Amazon Checkout extension for Magento 1.x
 *
 * (c) 2020 creativestyle GmbH. All Rights reserved
 *
 * Distribution of the derivatives reusing, transforming or being built upon
 * this software, is not allowed without explicit written permission granted
 * by creativestyle GmbH
 *
 * @category   Creativestyle
 * @package    Creativestyle_AmazonCheckout
 * @copyright  2020 creativestyle GmbH
 * @author     Marek Stefan <ticket@creativestyle.de>
 */

class Creativestyle_AmazonCheckout_Controller_Action extends Mage_Core_Controller_Front_Action
{
    /**
     * @var string[]
     */
    protected $_httpStatusCodes = array(
        100 => 'Continue',
        101 => 'Switching Protocols',

        200 => 'OK',
        201 => 'Created',
        202 => 'Accepted',
        203 => 'Non-Authoritative Information',
        204 => 'No Content',
        205 => 'Reset Content',
        206 => 'Partial Content',

        300 => 'Multiple Choices',
        301 => 'Moved Permanently',
        302 => 'Found',
        303 => 'See Other',
        304 => 'Not Modified',
        305 => 'Use Proxy',
        307 => 'Temporary Redirect',

        400 => 'Bad Request',
        401 => 'Unauthorized',
        402 => 'Payment Required',
        403 => 'Forbidden',
        404 => 'Not Found',
        405 => 'Method Not Allowed',
        406 => 'Not Acceptable',
        407 => 'Proxy Authentication Required',
        408 => 'Request Timeout',
        409 => 'Conflict',
        410 => 'Gone',
        411 => 'Length Required',
        412 => 'Precondition Failed',
        413 => 'Request Entity Too Large',
        414 => 'Request-URI Too Long',
        415 => 'Unsupported Media Type',
        416 => 'Requested Range Not Satisfiable',
        417 => 'Expectation Failed',

        500 => 'Internal Server Error',
        501 => 'Not Implemented',
        502 => 'Bad Gateway',
        503 => 'Service Unavailable',
        504 => 'Gateway Timeout',
        505 => 'HTTP Version Not Supported',
        509 => 'Bandwidth Limit Exceeded'
    );

    /**
     * @param Exception $e
     * @param int $code
     */
    protected function _setExceptionResponse(Exception $e, $code = 500)
    {
        $this->getResponse()->setHeader(
            'HTTP/1.1',
            sprintf('%s %s', $code, isset($this->_httpStatusCodes[$code]) ? $this->_httpStatusCodes[$code] : '')
        );

        if ($e instanceof Creativestyle_AmazonCheckout_Exception) {
            $this->getResponse()->setHeader('X-Amazon-Pay-Exception', $e->getUuid());
        }
    }

    /**
     * @param array|null $payload
     */
    protected function _setJsonResponse(array $payload = null)
    {
        $this->getResponse()->setHeader('Content-type','application/json');
        if (null !== $payload) {
            $this->getResponse()->setBody(json_encode($payload));
        }
    }

    /**
     * Return logger instance
     *
     * @return Creativestyle_AmazonCheckout_Model_Logger
     */
    protected function _getLogger()
    {
        /** @var Creativestyle_AmazonCheckout_Model_Logger $logger */
        $logger = Mage::getSingleton('amazonpay/logger');
        return $logger;
    }

    /**
     * Return instance of Magento core helper
     *
     * @return Mage_Core_Helper_Data
     */
    protected function _getCoreHelper()
    {
        /** @var Mage_Core_Helper_Data $helper */
        $helper = Mage::helper('core');
        return $helper;
    }

    /**
     * Return instance of Amazon Pay helper
     *
     * @return Creativestyle_AmazonCheckout_Helper_Data
     */
    protected function _getAmazonHelper()
    {
        /** @var Creativestyle_AmazonCheckout_Helper_Data $helper */
        $helper = Mage::helper('amazonpay');
        return $helper;
    }
}
