<?php
/**
 * This file is part of the official Amazon Checkout extension for Magento 1.x
 *
 * (c) 2020 creativestyle GmbH. All Rights reserved
 *
 * Distribution of the derivatives reusing, transforming or being built upon
 * this software, is not allowed without explicit written permission granted
 * by creativestyle GmbH
 *
 * @category   Creativestyle
 * @package    Creativestyle_AmazonCheckout
 * @copyright  2020 creativestyle GmbH
 * @author     Marek Stefan <ticket@creativestyle.de>
 */

class Creativestyle_AmazonCheckout_Model_DataMapper
{
    /**
     * Return instance of Amazon Pay helper
     *
     * @return Creativestyle_AmazonCheckout_Helper_Data
     */
    protected function _getAmazonHelper()
    {
        /** @var Creativestyle_AmazonCheckout_Helper_Data $helper */
        $helper = Mage::helper('amazonpay');
        return $helper;
    }

    /**
     * @param Creativestyle_AmazonCheckout_Model_Api_AddressInterface $from
     * @param Mage_Customer_Model_Address_Abstract $to
     * @api
     */
    public function mapAmazonPayAddress(
        Creativestyle_AmazonCheckout_Model_Api_AddressInterface $from,
        Mage_Customer_Model_Address_Abstract $to
    ) {
        $customerName = $this->_getAmazonHelper()->splitCustomerName($from->getName());
        $to->addData(array(
            'firstname' => $customerName->getFirstname(),
            'lastname' => $customerName->getLastname(),
            'city' => $from->getCity(),
            'postcode' => $from->getPostalCode(),
            'region' => $from->getStateOrRegion(),
            'country_id' => $from->getCountryCode(),
            'telephone' => $from->getPhoneNumber()
        ));
        $to->setStreet(array_filter(array(
            $from->getAddressLine1(),
            $from->getAddressLine2(),
            $from->getAddressLine3()
        ), function ($addressLine) { return $addressLine; }));
    }
}
