<?php
/**
 * This file is part of the official Amazon Checkout extension for Magento 1.x
 *
 * (c) 2020 creativestyle GmbH. All Rights reserved
 *
 * Distribution of the derivatives reusing, transforming or being built upon
 * this software, is not allowed without explicit written permission granted
 * by creativestyle GmbH
 *
 * @category   Creativestyle
 * @package    Creativestyle_AmazonCheckout
 * @copyright  2020 creativestyle GmbH
 * @author     Marek Stefan <ticket@creativestyle.de>
 */

class Creativestyle_AmazonCheckout_Model_Legacy_Config extends Creativestyle_AmazonPayments_Model_Config
{
    /**
     * Returns instance of Amazon Checkout v2 config object
     *
     * @return Creativestyle_AmazonCheckout_Model_Config
     */
    protected function _getConfig()
    {
        /** @var Creativestyle_AmazonCheckout_Model_Config $config */
        $config = Mage::getSingleton('amazonpay/config');
        return $config;
    }

    /**
     * This method overwrites the original isPayActive() method of the config object
     * by returning false if the Amazon Checkout v2 is enabled
     *
     * @param mixed|null $store
     * @return bool
     */
    public function isPayActive($store = null)
    {
        if ($this->_getConfig()->useLegacyExtension()) {
            return parent::isPayActive($store);
        }

        return false;
    }

    /**
     * This method overwrites the original isLoginActive() method of the config object
     * by returning false if the Amazon Checkout v2 is enabled
     *
     * @param mixed|null $store
     * @return bool
     */
    public function isLoginActive($store = null)
    {
        if ($this->_getConfig()->useLegacyExtension()) {
            return parent::isLoginActive($store);
        }

        return false;
    }
}
