<?php
/**
 * This file is part of the official Amazon Checkout extension for Magento 1.x
 *
 * (c) 2020 creativestyle GmbH. All Rights reserved
 *
 * Distribution of the derivatives reusing, transforming or being built upon
 * this software, is not allowed without explicit written permission granted
 * by creativestyle GmbH
 *
 * @category   Creativestyle
 * @package    Creativestyle_AmazonCheckout
 * @copyright  2020 creativestyle GmbH
 * @author     Marek Stefan <ticket@creativestyle.de>
 */

class Creativestyle_AmazonCheckout_Model_Resource_Setup extends Mage_Eav_Model_Entity_Setup
{
    protected function _getVersion()
    {
        return (string)$this->_moduleConfig->version;
    }

    /**
     * @param array $data
     * @throws Exception
     */
    protected function _copyConfigData(array $data)
    {
        foreach ($data as $oldConfigPath => $newConfigPath) {
            $query = $this->getConnection()->select()
                ->from($this->getTable('core/config_data'), '*')
                ->where('path = ?', $oldConfigPath);
            // @codingStandardsIgnoreStart
            $oldConfig = $this->getConnection()->fetchAll($query);
            // @codingStandardsIgnoreEnd
            if (!empty($oldConfig)) {
                $newConfig = array();
                foreach ($oldConfig as $row) {
                    // check if config entry with given path, scope and scope_id exists
                    $query = $this->getConnection()->select()
                        ->from($this->getTable('core/config_data'), 'COUNT(*)')
                        ->where('scope = ?', $row['scope'])
                        ->where('scope_id = ?', $row['scope_id'])
                        ->where('path = ?', $newConfigPath);
                    $count = $this->getConnection()->fetchOne($query);
                    if (!$count) {
                        $newConfig[] = array(
                            'scope' => $row['scope'],
                            'scope_id' => $row['scope_id'],
                            'path' => $newConfigPath,
                            'value' => $row['value']
                        );
                    }
                }

                if (!empty($newConfig)) {
                    try {
                        $this->getConnection()->beginTransaction();
                        $this->getConnection()->insertMultiple($this->getTable('core/config_data'), $newConfig);
                        $this->getConnection()->commit();
                    } catch (Exception $e) {
                        $this->getConnection()->rollback();
                        throw $e;
                    }
                }
            }
        }
    }

    /**
     * @throws Exception
     */
    public function migrateConfiguration()
    {
        $this->_copyConfigData(
            array(
                'amazonpayments/account/merchant_id' => 'amazonpay/account/merchant_id',
                'amazonpayments/account/client_id' => 'amazonpay/account/client_id',
                'amazonpayments/delivery_tracking/private_key' => 'amazonpay/account/private_key',
                'amazonpayments/delivery_tracking/public_key_id' => 'amazonpay/account/public_key_id',
                'amazonpayments/delivery_tracking/active' => 'amazonpay/alexa/active',
                'amazonpayments/delivery_tracking/carrier_codes' => 'amazonpay/alexa/carrier_codes',
                'amazonpayments/general/active' => 'amazonpay/general/active',
                'amazonpayments/general/login_active' => 'amazonpay/general/login_active',
                'amazonpayments/general/environment' => 'amazonpay/general/environment',
                'amazonpayments/general/language' => 'amazonpay/general/language',
                'amazonpayments/general/payment_action' => 'amazonpay/general/payment_action',
                'amazonpayments/design_login/pay_button_color' => 'amazonpay/design/pay_button_color',
                'amazonpayments/design_login/login_button_color' => 'amazonpay/design/login_button_color',
                'amazonpayments/store/name' => 'amazonpay/store/name',
                'amazonpayments/store/soft_descriptor' => 'amazonpay/store/soft_descriptor'
            )
        );
    }
}
